@@ -7,9 +7,7 @@ from django.test import TestCase, TransactionTestCase
 from django.utils.timezone import now
 from eveuniverse.models import EveSolarSystem, EveType
 
-from app_utils.testing import generate_invalid_pk
-
-from ..models import DiscordWebhook, NotificationRule, ScheduledNotification
+from ..models import DiscordWebhook, NotificationRule, ScheduledNotification, Timer
 from ..tasks import (
     notify_about_new_timer,
     schedule_notifications_for_rule,
@@ -17,7 +15,8 @@ from ..tasks import (
     send_messages_for_webhook,
     send_scheduled_notification,
 )
-from . import LoadTestDataMixin, create_fake_timer
+from .testdata.factory import create_timer
+from .testdata.fixtures import LoadTestDataMixin
 from .testdata.load_eveuniverse import load_eveuniverse
 
 MODULE_PATH = "structuretimers.tasks"
@@ -35,7 +34,7 @@ class TestCaseBase(LoadTestDataMixin, TestCase):
             scheduled_time=NotificationRule.MINUTES_15,
             webhook=self.webhook,
         )
-        self.timer = create_fake_timer(
+        self.timer = create_timer(
             structure_name="Test_1",
             eve_solar_system=self.system_abune,
             structure_type=self.type_raitaru,
@@ -52,12 +51,6 @@ class TestSendMessagesForWebhook(TestCaseBase):
         self.assertEqual(mock_logger.info.call_count, 2)
         self.assertEqual(mock_logger.error.call_count, 0)
 
-    def test_invalid_pk(self, mock_logger, mock_send_queued_messages):
-        send_messages_for_webhook(generate_invalid_pk(DiscordWebhook))
-        self.assertEqual(mock_send_queued_messages.call_count, 0)
-        self.assertEqual(mock_logger.info.call_count, 0)
-        self.assertEqual(mock_logger.error.call_count, 1)
-
     def test_disabled_webhook(self, mock_logger, mock_send_queued_messages):
         self.webhook.is_enabled = False
         self.webhook.save()
@@ -86,6 +79,16 @@ class TestScheduleNotificationForTimer(TestCaseBase):
             self.timer.scheduled_notifications.filter(notification_rule=self.rule)
         )
 
+    def test_should_not_create_notification_for_preliminary_timer(
+        self, mock_send_notification, mock_send_notification_for_timer
+    ):
+        # given
+        mock_send_notification.apply_async.return_value.task_id = "my_task_id"
+        timer = create_timer(timer_type=Timer.Type.PRELIMINARY)
+        # when/then
+        with self.assertRaises(ValueError):
+            schedule_notifications_for_timer(timer_pk=timer.pk, is_new=True)
+
     def test_remove_old_notifications(
         self, mock_send_notification, mock_send_notification_for_timer
     ):
@@ -214,7 +217,7 @@ class TestSendScheduledNotification(TransactionTestCase):
             scheduled_time=NotificationRule.MINUTES_15,
             webhook=self.webhook,
         )
-        self.timer = create_fake_timer(
+        self.timer = create_timer(
             structure_name="Test_1",
             eve_solar_system=self.system_abune,
             structure_type=self.type_raitaru,
